import {createEnhancedElement} from '@servicenow/library-enhanced-element';
import snabbdom from '@servicenow/ui-renderer-snabbdom';
import styles from './_now-highlighted-value.scss';
import '@servicenow/now-icon';

const NowHighlightedValue = (state) => {
	const {label = '', status, showIcon} = state.properties;
	return (
		<span
			class={{
				'now-highlighted-value': true,
				['-' + status]: status
			}}
			title={label}>
			{showIcon ? (
				<now-icon
					icon="presence-fill"
					size="sm"
					className="now-highlighted-value-icon"
					aria-hidden="true"
				/>
			) : (
				''
			)}
			<span className="now-highlighted-value-line-height-crop">
				<span className="now-highlighted-value-label">{label}</span>
			</span>
		</span>
	);
};

/**
 * Highlighted values communicate the value of an item
 * by promoting visibility and readability.
 *
 * Use highlighted values when you want to convey the status in a certain area,
 * such as a card, list, or widget. A highlighted value may be combined with a status icon.
 *
 * ```jsx
 * <now-highlighted-value label="Value" status="warning" show-icon>
 * </now-highlighted-value>
 * ```
 *
 * @seismicElement now-highlighted-value
 * @summary A styled label with an optional icon.
 */
createEnhancedElement('now-highlighted-value', {
	properties: {
		/**
		 * Text displayed as the highlighted value.
		 * @type {string}
		 */
		label: {},
		/**
		 * Sets the highlighted value color.
		 * @type {('critical'|'high'|'warning'|'moderate'|'positive'|'info'|'low')}
		 */
		status: {default: 'low'},
		/**
		 * Flag that determines whether an icon displays with the label.
		 * @type {boolean}
		 */
		showIcon: {default: false}
	},
	renderer: {
		type: snabbdom,
		view: NowHighlightedValue
	},
	styles
});
